library(lme4)
library(lmerTest)
library(emmeans)
library(nlme)
library (car)

library(ggplot2)

#############DATA################
data<-read.table("Assay 4 Negative Frequency Dependence.csv", header=TRUE, sep=",")
data$Day<-as.factor(data$Day)
data$Line<-as.factor(data$Line)

###########MODEL FOR ANALYSIS#############
model1<-lmer(Fitness~Initial*Day*Treatment+(1|Line), data=data)
Anova(model1, type=3)
summary(model1)

###########EFFECT SIZE AND CONFINTS########
lst<-emtrends(model1,~Day|Treatment, var="Initial")
pairs(lst)


#############PLOTTING###########
levels(data$Treatment)<-(c("Hard Selection", "Soft Selection"))

plot<-ggplot(data, aes(x=Initial, y=Fitness, color=Treatment))+
	facet_grid(~Treatment)+
	geom_point(size=2, aes(shape=Day))+

	ylim(0.7, NA)+
	stat_smooth(aes(linetype=Day, fill=Treatment),size=1, method='lm', se=T)+
    	scale_shape_manual(values=c(24, 15))+
	geom_hline(yintercept =1, linetype="dotted")+
	xlab("Frequency of resistance")+ylab("Relative fitness of resistance")+
	theme(panel.grid.major = element_blank(),
		panel.grid.minor = element_blank(),
		panel.border = element_blank(), 
		panel.background=element_blank()+
		theme(axis.line = element_line(colour = "black")))+
	labs(color="Treatment", linetype="Day", shape="Day")

###########OUTPUT##############
tiff("Assay 4.tiff", units="in", width=7, height=5, res=300)

plot+theme(legend.position="none",
	strip.background = element_blank(),
	strip.text = element_text(size = 15,hjust = 0),
	axis.text=element_text(size=10),
      axis.title=element_text(size=12))+
	guides(color=F, fill=F)

dev.off()
